# **Linked List**

## Utilisation

Il est possible de l'initialisé avec sois différentes valeurs sois un tableau de valeur.

- ```import linked_list```
- ```variable = linked_list(valeurs)```

## Fonctions

- ```ajouter(valeur)``` ajouter la valeur donné.
- ```inserer(index, valeur)``` insére la valeur donné à l'index donné.
- ```acceder(index)``` retourne la valeur de l'index donné.
- ```supprimer_ind(index)``` supprime la valeur à l'index donné.
- ```supprimer_val(valeur)``` supprime le premier élement correspondant à la valeur.
- ```remplacer(index, valeur)``` remplace la valeur à l'index donné.
- ```vider()``` vide la liste.
- ```vers_liste()``` convertie la liste enchainée en liste.
- ```copie()``` fait une copie profond de la liste enchainée

Et la majorité des fonctions des listes sont disponible pour cet objet



